'use strict';

const tv4 = require('tv4');

module.exports.validate = (objects, schema, flatten) => {

  if (!Array.isArray(objects)) throw new Error('objects parameter must contain an array.');

  if (typeof flatten == 'undefined') {
    flatten = true;
  }

  var errors = tv4.validateMultiple(objects, schema).errors;

  if (errors.length <= 0) {
    if (flatten) return flattenValues(objects);
    return true;
  }

  errors.forEach(function (error) {
    var data = error.dataPath.split('/');
    var index = data[1];
    var property = data[2];
    objects[index][property].valid = false;
  });

  if (flatten) return [];
  return false;
}

var flattenValues = (objects) => {
  var flattened = [];

  objects.forEach(obj => {
    var r = {}
    for (var prop in obj) {
      r[prop] = obj[prop].value;
    }
    flattened.push(r);
  });

  return flattened;
}

module.exports.setPristine = (objects) => {
  objects.forEach(obj => {
    for (var prop in obj) {
      if(typeof obj[prop] === 'object')
        obj[prop].valid = true;
    }
  })
}

module.exports.toValidationModel = (objects) => {
  var validatedObjects = [];
  objects.forEach(obj => {
    var transformedObject = {}
    for (var prop in obj) {
      var transformedProperty = {
        value: obj[prop],
        placeholder: '',
        error: '',
        valid: true
      }

      transformedObject[prop] = transformedProperty;
    }

    validatedObjects.push(transformedObject);
  });

  return validatedObjects;
}